@@ -3,6 +3,16 @@ package Ogre::Vector3;
 use strict;
 use warnings;
 
+# xxx: this should be in XS, but I can't get it to work
+use overload
+  '==' => \&eq_xs,
+  '!=' => \&ne_xs,
+  '<' => \&lt_xs,
+  '>' => \&gt_xs,
+  ;
+
+
+
 require Exporter;
 our @ISA = qw(Exporter);
 
